package com.elink.aicare;

/**
 * 调用体脂算法动态库
 */
import com.sun.jna.Library;
import com.sun.jna.Native;

public interface BodyFatAlgorithmAicare extends Library {
    String osName = System.getProperty("os.name");  // 获取当前操作系统的类型
    String rootResource = BodyFatAlgorithmAicare.class.getResource("/").getPath();
    String libWindows = "/libalgorithm-aicare.dll";
    String libMacOS = rootResource+ "libMacAlgorithm-aicare.so";
    //System调用so时，调用了：java.lang.System.mapLibraryName()方法。这个方法会在咱们的给定的名字前拼接上”lib”
    //此种调用方式，linux系统对应的so库，需要放在usr/lib下
    String liblinux = "algorithm-aicare";
    //根据不同的操作系统，使用不同的库
    String libPath = (osName != null && osName.startsWith("Windows")) ? libWindows : ((osName != null && osName.startsWith("Mac")) ? libMacOS : liblinux);
    BodyFatAlgorithmAicare INSTANTCE = (BodyFatAlgorithmAicare) Native.synchronizedLibrary(
            (BodyFatAlgorithmAicare) Native.loadLibrary(libPath, BodyFatAlgorithmAicare.class)
    );

    /**
     * 身高单位换算  CM 换算为 M
     * @param height 身高，单位：CM
     * @return 身高，单位：M
     */
    double getHeight(int height);

    /**
     * 计算用户BMI
     * @param weight 用户体重，单位：kg
     * @param height 用户身高，单位：M
     * @return 用户的BMI
     */
    double getBMI(double weight, double height);

    /**
     * 计算用户BM
     * @param sex
     * @param bmi
     * @param height
     * @param age
     * @param adc
     * @param weight
     * @return
     */
    double getBM(int sex, double bmi, double height, int age, int adc, double weight);

    /**
     * 计算用户ROM
     * @param sex
     * @param weight
     * @param height
     * @param age
     * @param adc
     * @return
     */
    double getROM(int sex, double weight, double height, int age, int adc);

    /**
     * 计算用户VMC
     * @param sex
     * @param bmi
     * @param adc
     * @param age
     * @return
     */
    double getVWC(int sex, double bmi, int adc, int age);

    /**
     * 计算用户BFR
     * @param sex
     * @param bmi
     * @param adc
     * @param age
     * @return
     */
    double getBFR(int sex, double bmi, int adc, int age);

    /**
     * 计算用户SFR
     * @param sex
     * @param age
     * @param bfr
     * @return
     */
    double getSFR(int sex, int age, double bfr);
    double getROSM(int age, int sex, double moi, double bfr);

    /**
     * 计算用户PP
     * @param bfr
     * @param moi
     * @param bm
     * @param weight
     * @param age
     * @param sex
     * @return
     */
    double getPP(double bfr, double moi, double bm, double weight, int age, int sex);

    /**
     * 计算用户UVI
     * @param sex
     * @param weight
     * @param height
     * @param age
     * @param adc
     * @return
     */
    int getUVI(int sex, double weight, double height, int age, int adc);

    /**
     * 计算用户BMR
     * @param sex
     * @param weight
     * @param height
     * @param age
     * @param adc
     * @return
     */
    int getBMR(int sex, double weight, double height, int age, int adc);

    /**
     * 计算用户BodyAge
     * @param age
     * @param bmi
     * @param sex
     * @return
     */
    int getBodyAge(int age, double bmi, int sex);
}
