package com.elink.aicare;

import com.alibaba.fastjson.JSON;

/**
 *
 */
public class BodyFatAlgorithmUtils {

    public static void main(String args[]){
        int sex=1;
        int age=24;
        double weight = 60.5;
        int height = 180;
        int adc = 500;
        System.out.println("品网算法");
        System.out.println(JSON.toJSONString(getBodyFatData(0,sex,age,weight,height,adc)));
    }

    /**
     * 获取基础身体指标
     * @param algorithmType 身体指标算法类型，可取值：0或1，0：品网算法；1：沃莱算法；
     *                     ps: 年龄、体重、身高、阻抗的取值范围仅当algorithmType=0时有效,超出取值范围，将返回空；
     * @param sex 性别，可取值：1或2；1：男；2：女
     * @param age 年龄，单位：年，取值范围：0<=age<=120
     * @param weight 体重；单位：kg，取值范围：0.0< weight < 220
     * @param height 身高；单位：cm，取值范围：0< height <=270
     * @param adc 阻抗；取值范围：0 < adc <= 1000
     * @return
     */
    public static BodyFatData getBodyFatData(int algorithmType,int sex, int age, double weight,int height, int adc){

            if (age < 0 || age > 120){
                System.out.println("年龄age取值不正确，取值范围：0<=age<=120 ；单位：年");
                return  null;
            }
            if (weight <= 0.0 && weight > 220.0){
                System.out.println("体重weight取值不正确，取值范围：0.0< weight < 220 ；单位：kg");
                return  null;
            }
            if (height <= 0 && height > 270){
                System.out.println("身高height取值不正确，取值范围：0< height <=270 ；单位：cm");
                return  null;
            }
            if (adc < 0 && adc > 1000){
                System.out.println("阻抗adc取值不正确，取值范围：0 < adc <= 1000");
                return  null;
            }
            return  getDataByAicare(sex, age, weight,height, adc);

    }

    private static BodyFatData getDataByAicare(int sex, int age, double weight,int heightCM, int adc){
        BodyFatAlgorithmAicare bodyFatAlgorithmAicare = BodyFatAlgorithmAicare.INSTANTCE;
        double height = bodyFatAlgorithmAicare.getHeight(heightCM);
        double bmi = bodyFatAlgorithmAicare.getBMI(weight,height);
        double bm = bodyFatAlgorithmAicare.getBM(sex,bmi,  height,  age,  adc,  weight);
        double rom = bodyFatAlgorithmAicare.getROM( sex,  weight,  height,  age,  adc);
        double vwc = bodyFatAlgorithmAicare.getVWC( sex,  bmi,  adc,  age);
        double bfr = bodyFatAlgorithmAicare.getBFR( sex,  bmi,  adc,  age);
        double sfr = bodyFatAlgorithmAicare.getSFR( sex,  age,  bfr);
        double rosm = bodyFatAlgorithmAicare.getROSM( age,  sex,  vwc,  bfr);
        double pp = bodyFatAlgorithmAicare.getPP( bfr,  vwc,  bm,  weight,  age,  sex);
        int uvi = bodyFatAlgorithmAicare.getUVI( sex,  weight,  height,  age,  adc);
        int bmr = bodyFatAlgorithmAicare.getBMR( sex,  weight,  height,  age,  adc);
        int bodyAge = bodyFatAlgorithmAicare.getBodyAge( age,  bmi,  sex);
        //处理返回数据
        BodyFatData fatData = new BodyFatData();
        fatData.setBmi(bmi);
        fatData.setBfr(Math.round(bfr * 10) / 10.0);
        fatData.setSfr(Math.floor(sfr * 10) / 10);
        fatData.setUvi(uvi);
        fatData.setRom(Math.floor(rom * 10) / 10);
        fatData.setBmr(bmr);
        fatData.setBm(Math.floor(bm * 10) / 10);
        fatData.setVwc(Math.floor(vwc * 10) / 10);
        fatData.setBodyAge(bodyAge);
        fatData.setPp(Math.floor(pp * 10) / 10);
        return fatData;
    }
}
